#
# spec file for package iodine
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2012 Malcolm J Lewis <malcolmlewis@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir /var/adm/fillup-templates
%endif

Name:           iodine
Version:        0.7.0
Release:        12.7
Summary:        IPv4-through-DNS tunnel server and client
License:        ISC
Group:          Productivity/Networking/System
URL:            http://code.kryo.se/iodine/
Source0:        http://code.kryo.se/iodine/iodine-%{version}.tar.gz
Source1:        iodine.service
Source2:        sysconfig.iodine
Source3:        iodined.service
Source4:        sysconfig.iodined
Source5:        system-user-iodined.conf
#PATCH-FIX-OPENSUSE iodine-fix-makefile-prefix.patch malcolmlewis@opensuse.org -- Modify default install prefix.
Patch0:         iodine-fix-makefile-prefix.patch
BuildRequires:  fdupes
BuildRequires:  zlib-devel
BuildRequires:  pkgconfig(systemd)
# iodine still uses ifconfig
Requires:       net-tools-deprecated
Requires(pre):  %fillup_prereq
%if 0%{?suse_version} >= 1500
Requires(pre):  group(nobody)
%endif
%if 0%{?suse_version} >= 1550
BuildRequires:  sysuser-tools
%sysusers_requires
%else
Requires(pre):  /usr/sbin/useradd
%endif

%description
This software lets one tunnel IPv4 data through a DNS server. This
can be usable in different situations where internet access is
firewalled, but DNS queries are allowed.

%prep
%autosetup -p1

%build
make PREFIX="%{_prefix}"
%if 0%{?suse_version} >= 1550
%sysusers_generate_pre %{SOURCE5} iodine system-user-iodined.conf
%endif

%install
make install PREFIX="%{buildroot}/%{_prefix}"
# Install client files
mkdir -p %{buildroot}%{_unitdir}
install -m 0644 %{S:1} %{buildroot}%{_unitdir}/
mkdir -p %{buildroot}%{_fillupdir}
install -m 0644 %{S:2} %{buildroot}%{_fillupdir}/
# Install server files
install -m 0644 %{S:3} %{buildroot}%{_unitdir}/
install -m 0644 %{S:4} %{buildroot}%{_fillupdir}/
# Copy common man page to avoid warning
pushd %{buildroot}%{_mandir}/man8/
cp %{name}.8 %{name}d.8
popd
# make chroot dir
mkdir -p %{buildroot}/var/lib/iodined
# make rc-link
ln -sf /usr/sbin/service %{buildroot}%{_sbindir}/rciodine
ln -sf /usr/sbin/service %{buildroot}%{_sbindir}/rciodined
%if 0%{?suse_version} >= 1550
mkdir -p %{buildroot}%{_sysusersdir}
install -m 0644 %{SOURCE5} %{buildroot}%{_sysusersdir}/
%endif

%if 0%{?suse_version} >= 1550
%pre -f iodine.pre
%else

%pre
/usr/sbin/useradd -r -d /var/lib/iodined -s /bin/false -c "user for iodine dns tunnel" -g nobody iodined 2> /dev/null || :
%endif
%service_add_pre iodine.service iodined.service

%post
%service_add_post iodine.service iodined.service
%{fillup_only -n iodine}
%{fillup_only -n iodined}

%preun
%service_del_preun iodine.service iodined.service

%postun
%service_del_postun iodine.service iodined.service

%files
%doc CHANGELOG README TODO
%{_sbindir}/%{name}
%{_sbindir}/%{name}d
%{_fillupdir}/sysconfig.iodine
%{_fillupdir}/sysconfig.iodined
%{_sbindir}/rciodine
%{_sbindir}/rciodined
%{_unitdir}/iodine.service
%{_unitdir}/iodined.service
%if 0%{?suse_version} >= 1550
%{_sysusersdir}/system-user-iodined.conf
%endif
%{_mandir}/man8/%{name}.8%{?ext_man}
%{_mandir}/man8/%{name}d.8%{?ext_man}
%attr(0700,iodined,nobody)/var/lib/iodined

%changelog
* Mon Oct 23 2023 malcolmlewis@opensuse.org
- Comment out ProtectDevices in hardening, (boo#1216238). Modified:
  * iodine.service.
  * iodined.service.
* Sun Sep  3 2023 malcolmlewis@opensuse.org
- Comment out ProtectClock in hardening, (boo#1206835). Modified:
  * iodine.service.
  * iodined.service.
* Wed Sep 22 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Modified:
  * iodine.service
  * iodined.service
* Sun Jun 13 2021 Callum Farmer <gmbr3@opensuse.org>
- Add now working CONFIG parameter to sysusers generator
* Tue Jun  8 2021 Jan Engelhardt <jengelh@inai.de>
- Use noun phrasing in descriptions.
- Use more modern rpm macros.
- Reduce sh code emissions of %%service_*.
* Sat Jun  5 2021 Callum Farmer <gmbr3@opensuse.org>
- Change to using systemd-sysusers
* Wed Jun 12 2019 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(systemd) instead of systemd: allow OBS to
  shortcut the build queues by allowing usage of systemd-mini
* Sun Jan  6 2019 Thomas Wagner <wagner-thomas@gmx.at>
- added dependency for ifconfig
* Thu Nov 23 2017 rbrown@suse.com
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468)
* Mon Mar 13 2017 malcolmlewis@opensuse.org
- Remove insserv requirement and macro to fix Factory build.
- Add fdupes check to avoid duplicate man page warning.
* Wed Dec 28 2016 wagner-thomas@gmx.at
- fixed unbalanced quotes in service files bnc#1017236
* Sat May  9 2015 wagner-thomas@gmx.at
- start iodine and iodined after network.target
- added rc-link
* Wed Aug 27 2014 wagner-thomas@gmx.at
- separate user for iodined
- added a default config (bnc#857181) with a chroot directory
- fixed license string
- Update to 0.7.0:
  * Artial IPv6 support (#107)
    Client can connect to iodined through an relaying IPv6
  nameserver. Server only supports IPv4 for now.
  Traffic inside tunnel is IPv4.
  * dd socket activation for systemd, by Michael Scherer.
  * Add automated lookup of external ip (via -n auto).
  * Bugfix for OS X (Can't assign requested address)
  * Fix DNS tunneling bug caused by uninitialized variable, #94
  * Handle spaces when entering password interactively, fixes
    [#93]. Patch by Hagar.
  * Add -R option to set OpenBSD routing domain for the DNS
    socket. Patch by laurent at gouloum fr, fixes #95.
  * Add android patches and makefile, from Marcel Bokhorst,
    fixes #105.
  * Added missing break in iodine.c, by Pavel Pergamenshchik,
    [#108].
  * A number of minor patches from Frank Denis, Gregor Herrmann
    and Barak A. Pearlmutter.
  + Testcase compilation fixes for OS X and FreeBSD
  + Do not let sockets be inherited by sub-processes, fixes
    [#99].
  + Add unspecified RR type (called PRIVATE; id 65399, in
    private use range). For servers with RFC3597 support.
    Fixes #97.
    + Fix authentication bypass vulnerability; found by Oscar
    Reparaz.
* Wed Sep 19 2012 malcolmlewis@opensuse.org
- Initial build.
- Add iodine-fix-makefile-prefix.patch: Modify default install
  prefix.
- Add systemd service and sysconfig files for both server and
  client.
